package org.w3c.rdfpic.ui;
import org.w3c.rdfpic.core.*;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JButton;
import javax.swing.JLabel;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.event.KeyEvent;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.net.URL;
import java.net.MalformedURLException;
import java.io.IOException;
import javax.swing.JOptionPane;

/**
 * CheckedDialog is a simple way to ask the user for <i>correct</i> string input.
 * For this purpose, a Checker instace must always check the input.  Only correct input will be accepted,
 * meaning the caller can shoot and forget, leaving the consequences to the Checker.
 */

public class CheckedDialog extends JDialog implements ActionListener
{
    JTextField textField;
    String msgID;
    Checker checker;
    String errTitle,errMessage;
    /**
     * Creates and initializes a CheckedDialog.
     * @param parent The parent frame.
     * @param checker The checker to deal with input.
     * @param msgID The msgID is passed to Checker to identify which request it is dealing with.
     * @param title The title of the message box displayed.
     * @param message The message the user sees.
     * @param errTitle The title of a popup error message if the input is not acceptable.
     * @param errMessage The message of the popup error dialog.
     * @param button The button of the input field.  Depending on the message you may choose an appropriate button.
     * @param blockInput If this is true, the parent will be locked (all input blocked) until an acceptable answer is found.
     */
    public CheckedDialog(JFrame parent,Checker checker,String msgID,String title, String message,String errTitle, String errMessage, JButton button,boolean blockInput)
    {
	super(parent,title,blockInput);
	this.msgID=msgID;
	this.checker=checker;
	if(errTitle==null) errTitle="";
	if(errMessage==null) errMessage="";
	if(message==null) message="";
	this.errMessage=errMessage;
	this.errTitle=errTitle;
	JPanel container=new JPanel();
	container.add(new JLabel(message));
	textField = new JTextField(20);
	textField.addActionListener(this);
	container.add(textField);
	button.addActionListener(this);
	container.add(button);
	setContentPane(container);
	pack();
	Rectangle r = parent.getBounds();
	Dimension dim = getSize();
	setLocation(r.x+(r.width-dim.width)/2, 
			  r.y+(r.height-dim.height)/2);
	setVisible(true);
    }

    public void actionPerformed(ActionEvent evt)//textField is OK
    {
	String text = textField.getText();
	if(checker.checkInput(msgID,text)) dispose();
	else
	    {
		JOptionPane.showMessageDialog(this,errMessage,errTitle,JOptionPane.WARNING_MESSAGE);
	    }
    }
}
